@@ -310,20 +310,23 @@ PYBIND11_MODULE(pyspiel, m) {
               {
                 extensions::loadBuckets();
               }, py::call_guard<py::gil_scoped_release>() )
- 
-      .def("test_sum", &extensions::test_sum)
-      .def("test_cfr", [](int idx, float val, py::array_t<float>& sharedStrategy, const py::dict& buckets)
+  
+        .def("discount", [](const float factor, py::array_t<float>& sharedRegret, py::array_t<float>& sharedStrategy)
               {
+                py::buffer_info regretBuf = sharedRegret.request();
+                const size_t N1 = regretBuf.ndim;
+                float *regretPtr = static_cast<float *>(regretBuf.ptr);
+ 
                 py::buffer_info stratBuf = sharedStrategy.request();
-                size_t N = stratBuf.ndim;
+                const size_t N2 = stratBuf.ndim;
                 float *stratPtr = static_cast<float *>(stratBuf.ptr);
+
+                assert(N1 == N2);
                 
-                // cast dict to cpp map
-                auto cppdict = buckets.cast<std::map<std::string, int>>();
-                return extensions::test_cfr(idx, val, stratPtr, cppdict); 
+                return extensions::discount(factor, regretPtr, stratPtr, N1); 
 
               }, py::call_guard<py::gil_scoped_release>() )
-      
+ 
       .def("cfr", [](int updatePlayerIdx, int time, float pruneThreshold, bool useRealTimeSearch, py::array_t<int> handIds, std::shared_ptr<const open_spiel::State> state, int currentStage, py::array_t<int>& sharedRegret, py::array_t<float>& sharedStrategy, py::array_t<float>& frozenSharedStrategy)
               { 
                 py::buffer_info handIdsBuf = handIds.request();
@@ -341,7 +344,7 @@ PYBIND11_MODULE(pyspiel, m) {
                 py::buffer_info frozenStratBuf = frozenSharedStrategy.request();
                 const size_t nFrozenStrat = frozenStratBuf.shape[0];
                 
-                float *frozenStratPtr = static_cast<float *>(frozenStratBuf.ptr); // TODO could use const but not necessary at this point
+                const float *frozenStratPtr = static_cast<float *>(frozenStratBuf.ptr); 
                 return extensions::cfr(updatePlayerIdx, time, pruneThreshold, useRealTimeSearch, handIdsPtr, handIdsSize, *state, currentStage, regPtr, nReg, stratPtr, nStrat, frozenStratPtr, nFrozenStrat);
 
               }, py::call_guard<py::gil_scoped_release>() )
@@ -361,7 +364,7 @@ PYBIND11_MODULE(pyspiel, m) {
                  
                 py::buffer_info frozenStratBuf = frozenSharedStrategy.request();
                 const size_t nFrozenStrat = frozenStratBuf.shape[0];
-                float *frozenStratPtr = static_cast<float *>(frozenStratBuf.ptr); // TODO could use const but not necessary at this point
+                const float *frozenStratPtr = static_cast<float *>(frozenStratBuf.ptr);
                 return extensions::multi_cfr(numIter, updatePlayerIdx, startTime, pruneThreshold, useRealTimeSearch, handIdsPtr, handIdsSize, *state, currentStage, regPtr, nReg, stratPtr, nStrat, frozenStratPtr, nFrozenStrat);
 
               }, py::call_guard<py::gil_scoped_release>() )
